@@ -714,15 +714,15 @@ gdm_welcome_session_spawn (GdmWelcomeSession *welcome_session)
 
         g_debug ("GdmWelcomeSession: Running welcome_session process: %s", welcome_session->priv->command);
 
+        if (welcome_session->priv->register_ck_session) {
+                open_welcome_session (welcome_session);
+        }
+
         res = start_dbus_daemon (welcome_session);
         if (! res) {
                 /* FIXME: */
         }
 
-        if (welcome_session->priv->register_ck_session) {
-                open_welcome_session (welcome_session);
-        }
-
         env = get_welcome_environment (welcome_session);
 
         error = NULL;
@@ -1122,14 +1122,14 @@ gdm_welcome_session_class_init (GdmWelcomeSessionClass *klass)
                                          g_param_spec_string ("user-name",
                                                               "user name",
                                                               "user name",
-                                                              "gdm",
+                                                              GDM_USERNAME,
                                                               G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
         g_object_class_install_property (object_class,
                                          PROP_GROUP_NAME,
                                          g_param_spec_string ("group-name",
                                                               "group name",
                                                               "group name",
-                                                              "gdm",
+                                                              GDM_GROUPNAME,
                                                               G_PARAM_READWRITE | G_PARAM_CONSTRUCT));
         g_object_class_install_property (object_class,
                                          PROP_SERVER_ADDRESS,
