@@ -129,7 +129,6 @@ struct GdmGreeterLoginWindowPrivate
         char            *timed_login_username;
         guint            timed_login_timeout_id;
 
-        guint            animation_timeout_id;
         guint            sensitize_power_buttons_timeout_id;
 
         guint            login_button_handler_id;
@@ -243,6 +242,8 @@ set_focus (GdmGreeterLoginWindow *login_window)
 
         if (GTK_WIDGET_REALIZED (entry) && ! GTK_WIDGET_HAS_FOCUS (entry)) {
                 gtk_widget_grab_focus (entry);
+        } else if (GTK_WIDGET_REALIZED (login_window->priv->user_chooser) && ! GTK_WIDGET_HAS_FOCUS (login_window->priv->user_chooser)) {
+                gtk_widget_grab_focus (login_window->priv->user_chooser);
         }
 }
 
@@ -755,7 +756,10 @@ reset_dialog (GdmGreeterLoginWindow *login_window)
 static void
 do_cancel (GdmGreeterLoginWindow *login_window)
 {
-        reset_dialog (login_window);
+        /* need to wait for response from backend */
+        set_message (login_window, _("Cancelling..."));
+        set_busy (login_window);
+        set_sensitive (login_window, FALSE);
         g_signal_emit (login_window, signals[CANCELLED], 0);
 }
 
@@ -764,6 +768,8 @@ gdm_greeter_login_window_ready (GdmGreeterLoginWindow *login_window)
 {
         g_return_val_if_fail (GDM_IS_GREETER_LOGIN_WINDOW (login_window), FALSE);
 
+        reset_dialog (login_window);
+
         set_sensitive (GDM_GREETER_LOGIN_WINDOW (login_window), TRUE);
         set_ready (GDM_GREETER_LOGIN_WINDOW (login_window));
         set_focus (GDM_GREETER_LOGIN_WINDOW (login_window));
@@ -1355,6 +1361,13 @@ shutdown_button_clicked (GtkButton             *button,
         do_system_stop (login_window);
 }
 
+static void
+on_users_loaded (GdmUserChooserWidget  *user_chooser,
+                 GdmGreeterLoginWindow *login_window)
+{
+        gdm_chooser_widget_activate_if_one_item (GDM_CHOOSER_WIDGET (login_window->priv->user_chooser));
+}
+
 static void
 on_user_chosen (GdmUserChooserWidget  *user_chooser,
                 GdmGreeterLoginWindow *login_window)
@@ -1362,6 +1375,8 @@ on_user_chosen (GdmUserChooserWidget  *user_chooser,
         char *user_name;
 
         user_name = gdm_user_chooser_widget_get_chosen_user_name (GDM_USER_CHOOSER_WIDGET (login_window->priv->user_chooser));
+        g_debug ("GdmGreeterLoginWindow: user chosen '%s'", user_name);
+
         if (user_name == NULL) {
                 return;
         }
@@ -1600,15 +1615,18 @@ load_theme (GdmGreeterLoginWindow *login_window)
         box = glade_xml_get_widget (login_window->priv->xml, "window-box");
         gtk_container_add (GTK_CONTAINER (login_window), box);
 
-        login_window->priv->user_chooser =
-                glade_xml_get_widget (login_window->priv->xml, "user-chooser");
-
+        login_window->priv->user_chooser = glade_xml_get_widget (login_window->priv->xml,
+                                                                 "user-chooser");
         if (login_window->priv->user_chooser == NULL) {
                 g_critical ("Userlist box not found");
         }
 
         gdm_user_chooser_widget_set_show_only_chosen (GDM_USER_CHOOSER_WIDGET (login_window->priv->user_chooser), TRUE);
 
+        g_signal_connect (login_window->priv->user_chooser,
+                          "loaded",
+                          G_CALLBACK (on_users_loaded),
+                          login_window);
         g_signal_connect (login_window->priv->user_chooser,
                           "activated",
                           G_CALLBACK (on_user_chosen),
@@ -1702,7 +1720,10 @@ gdm_greeter_login_window_size_request (GtkWidget      *widget,
         requisition->width += 2 * GTK_CONTAINER (widget)->border_width;
         requisition->height += 2 * GTK_CONTAINER (widget)->border_width;
 
-        requisition->width = MIN (requisition->width, .50 * screen_w);
+        /* Make width be at least 33% screen width
+         * and height be at most 80% of screen height
+         */
+        requisition->width = MAX (requisition->width, .33 * screen_w);
         requisition->height = MIN (requisition->height, .80 * screen_h);
 }
 
@@ -1910,7 +1931,7 @@ on_gconf_key_changed (GConfClient           *client,
                         update_banner_message (login_window);
                 }
         } else {
-                g_debug ("Config key not handled: %s", key);
+                g_debug ("GdmGreeterLoginWindow: Config key not handled: %s", key);
         }
 }
 
